
%define release_version 9
%define RHEV_AGENT_RUNNING /tmp/rhev-agent-running
%define _ovirt_version 1.0.8.1

Name: rhevm-guest-agent
Version: 1.0.8
Release: %{release_version}%{?dist}
Summary: RHEV-M Guest Agent
Group: Applications/System
License: ASL 2.0
URL: http://wiki.ovirt.org/wiki/Category:Ovirt_guest_agent
Source0: http://evilissimo.fedorapeople.org/releases/ovirt-guest-agent/%{version}/ovirt-guest-agent-%{_ovirt_version}.tar.bz2
BuildArch: noarch
BuildRoot: %(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)
Requires: dbus-python
Requires: rpm-python
Requires: python-ethtool >= 0.4-1
Requires: python-simplejson
Requires: udev >= 095-14.23
Requires: usermode
Provides: %{name} = %{version}-%{release}
Obsoletes: rhev-agent

Patch1: 0002-agent-updated-conf-file-and-replaced-ini-file-name.patch
Patch2: 0003-agent-enable-the-usb-redirector-rhbz-848799.patch
Patch3: 0006-Replaced-String-check-with-string-conversion.patch
Patch4: 0007-agent-Fix-python-2.4-compatibility.patch
Patch5: 0008-agent-Report-swap-usage-of-the-guests.patch

%description
This is the oVirt management agent running inside the guest. The agent
interfaces with the oVirt manager, supplying heart-beat info as well as
run-time data from within the guest itself. The agent also accepts
control commands to be run executed within the OS (like: shutdown and
restart).

%prep
%setup -q -n ovirt-guest-agent-%{version}

%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1

%configure --without-sso

sed -i 's/rhevm-guest-agent-common/rhevm-guest-agent/' ovirt-guest-agent/ovirt-guest-agent.conf

%install
make -C ovirt-guest-agent -f Makefile.el5 install DESTDIR=%{buildroot}

mkdir -p %{buildroot}%{_localstatedir}/log/ovirt-guest-agent
mkdir -p %{buildroot}%{_localstatedir}/lock/subsys/ovirt-guest-agent

install -m 755 ovirt-guest-agent/LockActiveSession.py %{buildroot}%{_datadir}/ovirt-guest-agent/LockActiveSession.py
ln -sf /usr/bin/consolehelper %{buildroot}%{_datadir}/ovirt-guest-agent/ovirt-shutdown
ln -sf /usr/bin/consolehelper %{buildroot}%{_datadir}/ovirt-guest-agent/ovirt-hibernate

%pretrans -p <lua>
--- If pid file exists
local result = posix.stat('/var/run/rhev-agent/rhev-agentd.pid')
if result then
    local file = io.open("%{RHEV_AGENT_RUNNING}", "w")
    io.close(file)
end

%posttrans
[ -e %{RHEV_AGENT_RUNNING} ] && { /bin/rm %{RHEV_AGENT_RUNNING}; \
    /sbin/service ovirt-guest-agent start; } || :

%pre
if [ "$1" -ge 1 ]; then
    # Previous version was not stopped on upgrade and it must be stopped
    # before change the user and group name.
    /sbin/service rhev-agentd status > /dev/null 2>&1 && \
        /sbin/service rhev-agentd stop > /dev/null 2>&1
fi

# The agent's user name was renamed from rhevagent to ovirtagent. So we delete
# the old user name and it will be created with the new user name.
getent passwd rhevagent > /dev/null && userdel rhevagent

getent group ovirtagent >/dev/null || groupadd -r -g 175 ovirtagent
getent passwd ovirtagent > /dev/null || \
    /usr/sbin/useradd -u 175 -g 175 -o -r ovirtagent \
    -c "oVirt Guest Agent" -d / -s /sbin/nologin
exit 0

%post
/sbin/chkconfig --add ovirt-guest-agent


%preun
if [ "$1" -eq 0 ]; then
    /sbin/service ovirt-guest-agent stop > /dev/null 2>&1
    /sbin/chkconfig --del ovirt-guest-agent

    # Send an "uninstalled" notification to vdsm.
    VIRTIO=`grep "^device" %{_sysconfdir}/ovirt-guest-agent.conf | awk '{ print $3; }'`
    if [ -w $VIRTIO ]
    then
        # Non blocking uninstalled notification
        echo -e '{"__name__": "uninstalled"}\n' | dd of=$VIRTIO \
            oflag=nonblock status=noxfer conv=nocreat 1>& /dev/null || :
    fi
fi

%postun

if [ "$1" -ge 1 ]; then
    /sbin/service ovirt-guest-agent condrestart > /dev/null 2>&1
fi

%files
%dir %attr (755,ovirtagent,ovirtagent) %{_localstatedir}/log/ovirt-guest-agent
%dir %attr (755,root,root) %{_datadir}/ovirt-guest-agent

%config(noreplace) %{_sysconfdir}/ovirt-guest-agent.conf

%doc AUTHORS COPYING NEWS README

# These are intentionally NOT 'noreplace' If this is modified by an user,
# this actually might break it.
%config %{_sysconfdir}/pam.d/ovirt-shutdown
%config %{_sysconfdir}/pam.d/ovirt-hibernate
%config %attr (644,root,root) %{_sysconfdir}/udev/rules.d/55-ovirt-guest-agent.rules
%config %{_sysconfdir}/security/console.apps/ovirt-shutdown
%config %{_sysconfdir}/security/console.apps/ovirt-hibernate
%attr (755,root,root) %{_datadir}/ovirt-guest-agent/ovirt-guest-agent.py*
%{_datadir}/ovirt-guest-agent/OVirtAgentLogic.py*
%{_datadir}/ovirt-guest-agent/VirtIoChannel.py*
%{_datadir}/ovirt-guest-agent/GuestAgentLinux2.py*
%{_datadir}/ovirt-guest-agent/LockActiveSession.py*
%{_datadir}/ovirt-guest-agent/ovirt-shutdown
%{_datadir}/ovirt-guest-agent/ovirt-hibernate
%attr (755,root,root) %{_datadir}/ovirt-guest-agent/hibernate
%attr (755,root,root) %{_sysconfdir}/init.d/ovirt-guest-agent

%changelog
* Mon Feb 18 2014 Vinzenz Feenstra <evilissimo@redhat.com> - 1.0.8-9
- Do not conflict with any kernel
Resolves: BZ#1048710

* Mon Jan 6 2014 Vinzenz Feenstra <evilissimo@redhat.com> - 1.0.8-8
- No longer requiring the kernel package but conflicting on kernel and
  kernel-PAE lower than required
Resolves: BZ#1048710

* Mon Dec 9 2013 Vinzenz Feenstra <evilissimo@redhat.com> - 1.0.8-7
- Fixed rhevm-guest-agent reporting
Resolves: BZ#1028006

* Wed Nov 6 2013 Vinzenz Feenstra <evilissimo@redhat.com> - 1.0.8-6
- New: Report swap usage and total swap size
Resolves: BZ#1031532

* Thu Aug 22 2013 Vinzenz Feenstra <vfeenstr@redhat.com> - 1.0.8-5
- Adding patch for replacing the string check
- Adding patch for python 2.4 syntax compatibility
Resolves: BZ#983408, BZ#1006861

* Thu Aug 22 2013 Vinzenz Feenstra <vfeenstr@redhat.com> - 1.0.8-3
- Fixed erasing of /usr/share/ovirt-guest-agent during removal (BZ#948173)
- Added required script 'LockActiveSession.py' (BZ#923775)
Resolves: BZ#948173, BZ#923775

* Mon Aug 19 2013 Vinzenz Feenstra <vfeenstr@redhat.com> - 1.0.8-2
- Updated to upstream version 1.0.8
Resolves: BZ#995465

* Tue Jun 11 2013 Vinzenz Feenstra <vfeenstr@redhat.com> - 1.0.7-9
- Solved: rhevm-guest-agent rpm causes installation failures in kickstart files
Resolves: BZ#975906

* Thu Apr 25 2013 Vinzenz Feenstra <vfeenstr@redhat.com> - 1.0.7-8
- Solved: Agent does not run when upgrading from rhev-agent to
  rhevm-guest-agent
Resolves: BZ#923812

* Fri Apr 19 2013 Vinzenz Feenstra <vfeenstr@redhat.com> - 1.0.7-5
- nonblocking uninstall message
Resolves: BZ#929387

* Fri Apr 19 2013 Vinzenz Feenstra <vfeenstr@redhat.com> - 1.0.7-4
- agent: Perform string sanitization on messages
Resolves: BZ#947014

* Tue Mar  5 2013 Vinzenz Feenstra <vfeenstr@redhat.com> - 1.0.7-3
- datadir as default home for the ovirtagent user
  Solves the issue with starting the service when polyinstantiated
  namespaces are used on the system.
  Following the Fedora guideline:
    http://fedoraproject.org/wiki/Packaging:UsersAndGroups
Resolves: BZ#883124

* Wed Jan 23 2013 Vinzenz Feenstra <vfeenstr@redhat.com> - 1.0.7-2
- Fix for "Only first IP on nic is reported"
- Fix for "vdsClient reports still old data after upgrade"
Resolves: BZ#753121, BZ#882268

* Wed Dec 26 2012 Gal Hammer <ghammer@redhat.com> - 1.0.7-1
- reset user rights on virtio-channel during package removal.
- unification of line endings to unix.
- fixed support for reporting devices with only ipv6.
- fixed pep8 errors in the linux guest agent.
- upstream build system is now taking care of folder creation.
- upstream build system is now taking care of systemd units installation.
Resolves: BZ#890275

* Sun Dec  2 2012 Gal Hammer <ghammer@redhat.com> - 1.0.4-4
- don't fail installation if old user (rhevagent) exists.
- updated conf file to include rhevm-guest-agent.
- obsoletes the rhev-agent package.
Resolves: BZ#881968 BZ#881970 BZ#881971

* Tue May  8 2012 Gal Hammer <ghammer@redhat.com> - 1.0.4-2
- replaced "with" usage with a python 2.4 compatible way.
- added files to support RHEL-5 distribution.
- added more detailed memory statistics.
- report agent old package name.
- package was renamed to rhevm-guest-agent in RHEL distribution.
- included a gpl-v2 copying file.
- added a support for RHEL distribution.
- added a support to hibernate (s4) command.
- renamed user name to ovirtguest.
- reset version numbering after changing the package name.
Resolves: BZ#803503

* Tue Dec 13 2011 Gal Hammer <ghammer@redhat.com> - 2.3.17-1
- do no change source code files in the "post" section.
Resolves: BZ#759843

* Tue Nov 15 2011 Gal Hammer <ghammer@redhat.com> - 2.3.16-3
- fixed symblic links removal on package upgrade.
Resolves: BZ#753074

* Thu Oct  6 2011 Gal Hammer <ghammer@redhat.com> - 2.3.16-1
- added xorg-x11-drv-qxl to the reported applications.
- fixed service name in service's status report.
Resolves: BZ#742766 BZ#743267

* Thu Sep 27 2011 Gal Hammer <ghammer@redhat.com> - 2.3.15-1
- fixed disk usage report when mount point include spaces.
- added a minimum version for python-ethtool.
- added a requirement for python-simplejson.
Resolves: BZ#736426

* Thu Sep 22 2011 Gal Hammer <ghammer@redhat.com> - 2.3.14-1
- added a new 'echo' command to support testing.
Resolves: BZ#736426

* Thu Sep 15 2011 Gal Hammer <ghammer@redhat.com> - 2.3.13-1
- report new network interaces information (ipv4, ipv6 and
  mac address).
- added disks usage report.
- a new json-based protocol with the vdsm.
Resolves: BZ#729252 BZ#736426

* Mon Aug  8 2011 Gal Hammer <ghammer@redhat.com> - 2.3.12-1
- replaced password masking with a fixed-length string.
Resolves: BZ#727506

* Thu Aug  4 2011 Gal Hammer <ghammer@redhat.com> - 2.3.11-1
- send an 'uninstalled' notification to vdsm
- mask the user's password in the credentials block
Resolves: BZ#727647 BZ#727506

* Mon Jul 25 2011 Gal Hammer <ghammer@redhat.com> - 2.3.10-1
- various fixes after failing the errata's rpmdiff.
Resolves: BZ#720144

* Thu Jun 16 2011 Gal Hammer <ghammer@redhat.com> - 2.3.9-1
- read report rate values from configuration file.
- replaced executing privilege commands from sudo to
  consolehelper.
Resolves: BZ#713079 BZ#632959

* Tue Jun 14 2011 Gal Hammer <ghammer@redhat.com> - 2.3.8-1
- execute the agent with a non-root user.
- changed the shutdown timeout value to work in minutes.
Resolves: BZ#632959 BZ#711428

* Tue May 25 2011 Gal Hammer <ghammer@redhat.com> - 2.3.7-1
- show only network interfaces that are up and running.
Resolves: BZ#704845

* Thu Mar 10 2011 Gal Hammer <ghammer@redhat.com> - 2.3.4-1
- added some sleep-ing to init script in order to give udev
  some time to create the symbolic links.
- changed the kernel version condition.
Resolves: BZ#676625 BZ#681527

* Wed Mar 2 2011 Gal Hammer <ghammer@redhat.com> - 2.3.3-1
- removed unused file (rhevcredserver) from rhel-5 build.
- added udev and kernel minimum version requirment.
- fixed pid file location in spec file.
Resolves: BZ#681524 BZ#681527 BZ#681533

* Tue Mar 1 2011 Gal Hammer <ghammer@redhat.com> - 2.3.2-1
- updated the agent's makefile to work with auto-tools.
- added sub packages to support the single-sign-on feature.
- added -h parameter to shutdown command in order to halt the vm
  after shutdown.
- converted configuration file to have unix-style line ending.
- added redhat-rpm-config to build requirements in order to
  include *.pyc and *.pyo in the rpm file.
Resolves: BZ#680107 BZ#661713 BZ#679470 BZ#679451

* Wed Jan 19 2011 Gal Hammer <ghammer@redhat.com> - 2.3-7
- fixed files' mode to include execution flag.
Resolves: BZ#670476

* Mon Jan 17 2011 Gal Hammer <ghammer@redhat.com> - 2.3-6
- fixed the way the exit code was returned. the script always
  return 0 (success) because the main program ended and errors
  from the child process were lost.
Resolves: BZ#658092

* Thu Dec 23 2010 Gal Hammer <ghammer@redhat.com> - 2.3-5
- added description to startup/shutdown script in order to support
  chkconfig.
- a temporary fix to the 100% cpu usage when the vdsm doesn't
  listen to the virtio-serial.
Resolves: BZ#639702

* Sun Dec 19 2010 Gal Hammer <ghammer@redhat.com> - 2.3-4
- BZ#641886: lock command now handle both gnome and kde.
Resolves: BZ#641886

* Tue Dec 07 2010 Barak Azulay <bazulay@redhat.com> - 2.3-3
- BZ#660343 load virtio_console module before starting the daemon.
- BZ#660231 register daemon for startup.
Resolves: BZ#660343 BZ#660231

* Wed Dec 05 2010 Barak Azulay <bazulay@redhat.com> - 2.3-2
- initial build for RHEL-6
- works over vioserial
- Agent reports only heartbeats, IPs, app list
- performs: shutdown & lock (the lock works only on gnome - when
  ConsoleKit & gnome-screensaver is installed)
Resolves: BZ#613059
  
* Thu Aug 27 2010 Gal Hammer <ghammer@redhat.com> - 2.3-1
- Initial build.
